# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this
project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.0] - 2022-10-18
* Added python-datamodel as dependency for build Dataclasses.
* replaced rapidjson with orjson.
* fix some issues in publish-to-pypi GH.
* Adding support for in-memory config dictionary based on YAML or TOML
* Config Readers from Memcache and Redis
* Support for replacing INI files with TOML or YAML configuration files.

## [0.9.1] - 2021-10-20
* First stable version with support to Python +3.8
* Fixing issues over pyproject.toml
